@@ -37,12 +37,17 @@ class Player(pygame.sprite.Sprite):
 
         self.index = 0
         self.image = self.images[self.index]
-        self.rect = pygame.Rect(250, 575, 600, 600)
+        # self.rect = pygame.Rect(250, 575, 600, 600)
+        self.rect = pygame.Rect(theScreen.width / 5, theScreen.height / 1.6, 600, 600)
 
-    def resize(self, scale):
-        self.height = self.height * scale
-        self.width = self.width * scale
-        self.image = pygame.transform.rotozoom(self.images[self.index], 0, scale)
+    # def resize(self, scale):
+    #     self.height = self.height * scale
+    #     self.width = self.width * scale
+    #     self.image = pygame.transform.rotozoom(self.images[self.index], 0, scale)
+
+    def resize(self):
+        self.rect = pygame.Rect(theScreen.width/5, theScreen.height/1.6, 600, 600)
+        # self.image = pygame.transform.rotozoom(self.images[self.index], 0, theScreen.width/200)
 
     def update(self):
         self.index += 1
@@ -50,10 +55,10 @@ class Player(pygame.sprite.Sprite):
             self.index = 0
         self.image = self.images[self.index]
 
-    def changeLocation(self, x, y):
-        self.x = x
-        self.y = y
-        self.rect = pygame.Rect(x, y, self.width, self.height)
+    # def changeLocation(self, x, y):
+    #     self.x = x
+    #     self.y = y
+    #     self.rect = pygame.Rect(x, y, self.width, self.height)
 
 class Coffee(pygame.sprite.Sprite):
     def __init__(self):
@@ -68,7 +73,8 @@ class Coffee(pygame.sprite.Sprite):
 
         self.index = 0
         self.image = self.images[self.index]
-        self.rect = pygame.Rect(1000, 450, 500, 500)
+        # self.rect = pygame.Rect(1000, 450, 500, 500)
+        self.rect = pygame.Rect(theScreen.width/1.5, theScreen.height/2, 600, 600)
 
     def update(self):
         self.index += 1
@@ -76,15 +82,18 @@ class Coffee(pygame.sprite.Sprite):
             self.index = 0
         self.image = self.images[self.index]
 
-    def resize(self, scale):
-        self.height = self.height * scale
-        self.width = self.width * scale
-        self.image = pygame.transform.rotozoom(self.images[self.index], 0, scale)
+    def resize(self):
+        self.rect = pygame.Rect(theScreen.width/1.5, theScreen.height/2, 600, 600)
 
-    def changeLocation(self, x, y):
-        self.x = x
-        self.y = y
-        self.rect = pygame.Rect(x, y, self.width, self.height)
+    # def resize(self, scale):
+    #     self.height = self.height * scale
+    #     self.width = self.width * scale
+    #     self.image = pygame.transform.rotozoom(self.images[self.index], 0, scale)
+    #
+    # def changeLocation(self, x, y):
+    #     self.x = x
+    #     self.y = y
+    #     self.rect = pygame.Rect(x, y, self.width, self.height)
 
 class Ruby(pygame.sprite.Sprite):
     def __init__(self):
@@ -102,7 +111,8 @@ class Ruby(pygame.sprite.Sprite):
 
         self.index = 0
         self.image = self.images[self.index]
-        self.rect = pygame.Rect(800, 350, 500, 500)
+        # self.rect = pygame.Rect(800, 350, 500, 500)
+        self.rect = pygame.Rect(theScreen.width / 2, theScreen.height / 2.5, 600, 600)
 
     def update(self):
         self.index += 1
@@ -110,15 +120,18 @@ class Ruby(pygame.sprite.Sprite):
             self.index = 0
         self.image = self.images[self.index]
 
-    def resize(self, scale):
-        self.height = self.height * scale
-        self.width = self.width * scale
-        self.image = pygame.transform.rotozoom(self.images[self.index], 0, scale)
+    def resize(self):
+        self.rect = pygame.Rect(theScreen.width/2, theScreen.height/2.5, 600, 600)
 
-    def changeLocation(self, x, y):
-        self.x = x
-        self.y = y
-        self.rect = pygame.Rect(x, y, self.width, self.height)
+    # def resize(self, scale):
+    #     self.height = self.height * scale
+    #     self.width = self.width * scale
+    #     self.image = pygame.transform.rotozoom(self.images[self.index], 0, scale)
+
+    # def changeLocation(self, x, y):
+    #     self.x = x
+    #     self.y = y
+    #     self.rect = pygame.Rect(x, y, self.width, self.height)
 
 class Eye(pygame.sprite.Sprite):
     def __init__(self):
@@ -132,7 +145,8 @@ class Eye(pygame.sprite.Sprite):
 
         self.index = 0
         self.image = self.images[self.index]
-        self.rect = pygame.Rect(850, 400, 500, 500)
+        # self.rect = pygame.Rect(850, 400, 500, 500)
+        self.rect = pygame.Rect(theScreen.width/2, theScreen.height/2.5, 600, 600)
 
     def update(self):
         self.index += 1
@@ -140,15 +154,18 @@ class Eye(pygame.sprite.Sprite):
             self.index = 0
         self.image = self.images[self.index]
 
-    def resize(self, scale):
-        self.height = self.height * scale
-        self.width = self.width * scale
-        self.image = pygame.transform.rotozoom(self.images[self.index], 0, scale)
+    def resize(self):
+        self.rect = pygame.Rect(theScreen.width/2, theScreen.height/2.5, 600, 600)
 
-    def changeLocation(self, x, y):
-        self.x = x
-        self.y = y
-        self.rect = pygame.Rect(x, y, self.width, self.height)
+    # def resize(self, scale):
+    #     self.height = self.height * scale
+    #     self.width = self.width * scale
+    #     self.image = pygame.transform.rotozoom(self.images[self.index], 0, scale)
+    #
+    # def changeLocation(self, x, y):
+    #     self.x = x
+    #     self.y = y
+    #     self.rect = pygame.Rect(x, y, self.width, self.height)
 
 #-----from questions.py-----#
 def initialize(filename):
@@ -335,13 +352,9 @@ class healthBar():
             # screen.blit(text, text_rect)
         pygame.display.update()
 
-# class level():
-#     def __init__(self, level):
-#         self.level = level
-
 #-----initialize objects etc-----#
 ws = initialize("python_questions.xlsx")
-screen = pygame.display.set_mode((0, 0), pygame.RESIZABLE)
+screen = pygame.display.set_mode((0,0), pygame.RESIZABLE)
 white = (255, 255, 255)
 purple = (110, 113, 198)
 blue = (64, 127, 194)
@@ -354,7 +367,6 @@ gold = (197, 179, 88)
 lime = (153, 255, 51)
 width = screen.get_width()
 height = screen.get_height()
-#screen.fill(lime)
 
 clock = pygame.time.Clock()
 theScreen = Screen(screen.get_width(), screen.get_height())
@@ -412,16 +424,25 @@ changeHistory = button(color_light, (width * 0.25), (height * 8 / 14), (width *
                                       "Use History Deck")
 
 #options -> change sound settings
+sound = True
 sound_header = text(black, (width * 0.25), (height * 0 / 12), (width * 0.5), (height * 2 / 10), 150,
                                ["SOUND SETTINGS"])
-mute_button = button(color_light, (width * 0.25), (height * 3 / 12), (width * 0.5), (height * 2 / 10),
+mute_button = button(color_light, (width * 0.24), (height * 2.5 / 12), (width * 0.25), (height * 1 / 14),
                                       "Mute")
-unmute_button = button(color_light, (width * 0.25), (height * 3 / 12), (width * 0.5), (height * 2 / 10),
+unmute_button = button(color_light, (width * 0.51), (height * 2.5 / 12), (width * 0.25), (height * 1 / 14),
                                       "Unmute")
-volume_label = text(black,(width * 0.25), (height * 6 / 12), (width * 0.5), (height * 2 / 10), 100,
-                               ["Volume"])
-#volume_minus
-#volume_plus
+music_label = text(black,(width * 0.25), (height * 3.25 / 12), (width * 0.5), (height * 2 / 14), 75,
+                               ["Choose lobby music:"])
+music_choice_1 = button(color_light, (width * 0.235), (height * 4.8 / 12), (width * 0.167), (height * 2 / 14),
+                                      "8-bit")
+music_choice_2 = button(color_light, (width * 0.4175), (height * 4.8 / 12), (width * 0.167), (height * 2 / 14),
+                                      "Elf")
+music_choice_3 = button(color_light, (width * 0.6), (height * 4.8 / 12), (width * 0.167), (height * 2 / 14),
+                                      "Latin")
+music_choice_4 = button(color_light, (width * 0.24), (height * 6.8 / 12), (width * 0.25), (height * 2 / 14),
+                                      "Sinatra")
+music_choice_5 = button(color_light, (width * 0.51), (height * 6.8 / 12), (width * 0.25), (height * 2 / 14),
+                                      "Rick n' Roll")
 
 
 def resize(startWidth, startHeight):
@@ -461,9 +482,14 @@ def resize(startWidth, startHeight):
 
     #options -> change sound settings menu
     sound_header.modify((startWidth * 0.25), (startHeight * 0 / 12), (startWidth * 0.5), (startHeight * 2 / 10))
-    mute_button.modify((startWidth * 0.25), (startHeight * 3 / 12), (startWidth * 0.5), (startHeight * 2 / 10))
-    unmute_button.modify((startWidth * 0.25), (startHeight * 3 / 12), (startWidth * 0.5), (startHeight * 2 / 10))
-    volume_label.modify((startWidth * 0.25), (startHeight * 6 / 12), (startWidth * 0.5), (startHeight * 2 / 10))
+    mute_button.modify((startWidth * 0.24), (startHeight * 2.5 / 12), (startWidth * 0.25), (startHeight * 1 / 14))
+    unmute_button.modify((startWidth * 0.51), (startHeight * 2.5 / 12), (startWidth * 0.25), (startHeight * 1 / 14))
+    music_label.modify((startWidth * 0.25), (startHeight * 3.25 / 12), (startWidth * 0.5), (startHeight * 2 / 14))
+    music_choice_1.modify((startWidth * 0.235), (startHeight * 4.8 / 12), (startWidth * 0.167), (startHeight * 2 / 14))
+    music_choice_2.modify((startWidth * 0.4175), (startHeight * 4.8 / 12), (startWidth * 0.167), (startHeight * 2 / 14))
+    music_choice_3.modify((startWidth * 0.6), (startHeight * 4.8 / 12), (startWidth * 0.167), (startHeight * 2 / 14))
+    music_choice_4.modify((startWidth * 0.24), (startHeight * 6.8 / 12), (startWidth * 0.25), (startHeight * 2 / 14))
+    music_choice_5.modify((startWidth * 0.51), (startHeight * 6.8 / 12), (startWidth * 0.25), (startHeight * 2 / 14))
 
 def reDrawStartWindow():
     screen.fill(gold)
@@ -525,7 +551,7 @@ def drawCategories(color, text_color):
     cat4.draw(screen, int(theScreen.width * 0.02), text_color, False)
     cat5.draw(screen, int(theScreen.width * 0.02), text_color, False)
 
-def chooseCategory(playerGroup, enemyGroup,level,color,text_color):
+def chooseCategory(playerGroup, enemyGroup,level,color,text_color,myPlayer,myEnemy):
     drawCategories(color, text_color)
     while True:
         for ev in pygame.event.get():
@@ -561,6 +587,10 @@ def chooseCategory(playerGroup, enemyGroup,level,color,text_color):
 
                 pygame.display.set_mode((theScreen.width, theScreen.height), pygame.RESIZABLE)
                 resizeBattle(theScreen.width, theScreen.height)
+                myPlayer.resize()
+                playerGroup = pygame.sprite.Group(myPlayer)
+                myEnemy.resize()
+                enemyGroup = pygame.sprite.Group(myEnemy)
                 drawBattle(playerGroup, enemyGroup, theScreen.width, theScreen.height,level)
                 drawCategories(color, text_color)
 
@@ -589,7 +619,7 @@ def drawAnswers(text_color):
     c.draw(screen, int(theScreen.width * 0.02), text_color, False)
     d.draw(screen, int(theScreen.width * 0.02), text_color, False)
 
-def chooseAnswer(playerGroup, enemyGroup, question ,level,q,A,B,C,D, text_color):
+def chooseAnswer(playerGroup, enemyGroup, question ,level,q,A,B,C,D, text_color,myPlayer,myEnemy):
     drawAnswers(text_color)
     while True:
         for ev in pygame.event.get():
@@ -618,6 +648,10 @@ def chooseAnswer(playerGroup, enemyGroup, question ,level,q,A,B,C,D, text_color)
 
                 pygame.display.set_mode((theScreen.width, theScreen.height), pygame.RESIZABLE)
                 resizeBattle(theScreen.width, theScreen.height)
+                myPlayer.resize()
+                playerGroup = pygame.sprite.Group(myPlayer)
+                myEnemy.resize()
+                enemyGroup = pygame.sprite.Group(myEnemy)
                 drawBattle(playerGroup, enemyGroup, theScreen.width, theScreen.height,level)
 
                 q.modify(theScreen.width * 0.25, theScreen.height * 1/9, 50, 50)
@@ -662,19 +696,19 @@ def drawBackground(playerGroup, enemyGroup, width, height, level, correctOrWrong
         bg = pygame.transform.rotozoom(bg, 0, theScreen.width / 1400)
     else:
         bg = pygame.image.load("ocean.jpg")
-        bg = pygame.transform.rotozoom(bg, 0, theScreen.width / 1900)
+        bg = pygame.transform.rotozoom(bg, 0, theScreen.width / 1850)
     screen.blit(bg,(0,0))
     if correctOrWrong != "":
         if correctOrWrong == "Correct":
             #pygame.mixer.Sound("correct.wav").play(0)
             display = text(black, theScreen.width * 0.25, theScreen.height * 0.2, theScreen.width * 0.5,
                                   theScreen.height * 0.4, int(theScreen.width * 0.02), ["Correct"])
-            pygame.draw.rect(screen, (0,255,0), (theScreen.width * 0.35, theScreen.height * 0.3, theScreen.width * 0.3, theScreen.height * 0.2))
+            pygame.draw.ellipse(screen, (0, 200, 0), (theScreen.width * 0.35, theScreen.height * 0.3, theScreen.width * 0.3, theScreen.height * 0.2))
         if correctOrWrong == "Wrong":
             #pygame.mixer.Sound("incorrect.wav").play(0)
             display = text(black, theScreen.width * 0.25, theScreen.height * 0.2, theScreen.width * 0.5,
                                   theScreen.height * 0.4, int(theScreen.width * 0.02), ["Incorrect"])
-            pygame.draw.rect(screen, (255, 0, 0), (theScreen.width * 0.35, theScreen.height * 0.3, theScreen.width * 0.3, theScreen.height * 0.2))
+            pygame.draw.ellipse(screen, (255, 0, 0), (theScreen.width * 0.35, theScreen.height * 0.3, theScreen.width * 0.3, theScreen.height * 0.2))
         display.draw(screen, int(theScreen.width * 1/16), True)
     # playerGroup.draw(screen)
     # enemyGroup.draw(screen)
@@ -725,12 +759,14 @@ def animationController(playerGroup, enemyGroup, width, height, clock, level, an
         playerGroup.draw(screen)
         pygame.display.update()
         clock.tick(3)
+
         drawBackground(playerGroup, enemyGroup, width, height,level, "Wrong")
         enemyGroup.update()
         enemyGroup.draw(screen)
         playerGroup.draw(screen)
         pygame.display.update()
         clock.tick(3)
+
         drawBackground(playerGroup, enemyGroup, width, height,level, "Wrong")
         enemyGroup.update()
         enemyGroup.update()
@@ -755,6 +791,7 @@ def animationController(playerGroup, enemyGroup, width, height, clock, level, an
         playerGroup.draw(screen)
         enemyGroup.draw(screen)
         pygame.display.update()
+
     if (animation == "coffee break"):
         clock.tick(2)
         for i in range (0,6):
@@ -781,26 +818,31 @@ def animationController(playerGroup, enemyGroup, width, height, clock, level, an
             enemyGroup.draw(screen)
             pygame.display.update()
             clock.tick(5)
+
         drawBackground(playerGroup, enemyGroup, width, height,level, "Wrong")
         enemyGroup.update()
         enemyGroup.update()
         playerGroup.draw(screen)
         enemyGroup.draw(screen)
         pygame.display.update()
+
     if (animation == "ruby hurt"):
         for i in range(0, 7):
             enemyGroup.update()
+
         drawBackground(playerGroup, enemyGroup, width, height,level, "Correct")
         enemyGroup.update()
         playerGroup.draw(screen)
         enemyGroup.draw(screen)
         pygame.display.update()
         clock.tick(3)
+
         drawBackground(playerGroup, enemyGroup, width, height,level, "Correct")
         enemyGroup.update()
         playerGroup.draw(screen)
         enemyGroup.draw(screen)
         pygame.display.update()
+
     if (animation == "eye attack"):
         for i in range(0, 2):
             drawBackground(playerGroup, enemyGroup, width, height, level, "Wrong")
@@ -809,28 +851,32 @@ def animationController(playerGroup, enemyGroup, width, height, clock, level, an
             enemyGroup.draw(screen)
             pygame.display.update()
             clock.tick(2)
+
         drawBackground(playerGroup, enemyGroup, width, height, level, "Wrong")
         enemyGroup.update()
         enemyGroup.update()
         playerGroup.draw(screen)
         enemyGroup.draw(screen)
         pygame.display.update()
+
     if (animation == "eye hurt"):
         for i in range(0, 2):
             enemyGroup.update()
+
         drawBackground(playerGroup, enemyGroup, width, height, level, "Correct")
         enemyGroup.update()
         playerGroup.draw(screen)
         enemyGroup.draw(screen)
         pygame.display.update()
         clock.tick(3)
+
         drawBackground(playerGroup, enemyGroup, width, height, level, "Correct")
         enemyGroup.update()
         playerGroup.draw(screen)
         enemyGroup.draw(screen)
         pygame.display.update()
 
-def theBattle(level, sounds=True):
+def theBattle(level, sound):
     health = 100
     enemy_health = 100
     userHealth.set_health(health)
@@ -846,31 +892,34 @@ def theBattle(level, sounds=True):
     cat_button_color = white
     ans_button_color = white
     text_color = white
-
+    # level = 3
     if level == 1:
         myEnemy = Coffee()
-        if sounds:
+        if sound:
             pygame.mixer.music.load('jazz.mp3')
             pygame.mixer.music.play(-1)
-        text_color = (108, 16, 40)
-        cat_button_color = (171, 92, 187)
-        ans_button_color = color_light
+        text_color = black
+        cat_button_color = (215,132,37)#(122,135,117)
+        ans_button_color = (217,125,19)
+        box_color = (77, 160, 83, 130)
     elif level == 2:
         myEnemy = Ruby()
-        if sounds:
+        if sound:
             pygame.mixer.music.load('funke.mp3')
             pygame.mixer.music.play(-1)
         cat_button_color = (240,208,79)
-        text_color = color_light
+        text_color = (204,203,194)
         ans_button_color = color_dark
+        box_color = (0,0,0,0)
     else:
         myEnemy = Eye()
-        if sounds:
+        if sound:
             pygame.mixer.music.load('bluth.wav')
             pygame.mixer.music.play(-1)
-        cat_button_color = color_dark
-        text_color = color_light
-        ans_button_color = color_dark
+        cat_button_color = (12,37,99)
+        text_color = (170,171,173)
+        ans_button_color = (1,26,41)
+        box_color = (0,0,0,0)
 
     enemyGroup = pygame.sprite.Group(myEnemy)
     # enemyGroup.draw(screen)
@@ -878,6 +927,8 @@ def theBattle(level, sounds=True):
 
     battle = True
     while battle:
+        # myPlayer.resize()
+        # playerGroup = pygame.sprite.Group(myPlayer)
         clock.tick(27)
         userHealth.modify(0.02 * theScreen.width, 0.02 * theScreen.height, theScreen.width * 0.1,
                           theScreen.height * 0.03)
@@ -886,29 +937,33 @@ def theBattle(level, sounds=True):
         # enemyGroup.draw(screen)
         # playerGroup.draw(screen)
         drawBattle(playerGroup, enemyGroup, theScreen.width, theScreen.height,level)
-        choose = chooseCategory(playerGroup, enemyGroup, level, cat_button_color, text_color)
+        choose = chooseCategory(playerGroup, enemyGroup, level, cat_button_color, text_color,myPlayer,myEnemy)
         print(choose)
         questionNumber = load_question(choose)
         question = get_question(questionNumber, ws)
 
         drawBattle(playerGroup, enemyGroup, theScreen.width, theScreen.height,level)
 
+        #ellipse
+        pygame.draw.ellipse(screen, box_color, (0, int(theScreen.height * 0.1), int(theScreen.width), int(theScreen.height * 0.1)))
+
         q = text(text_color, theScreen.width * 0.25, theScreen.height * 1/9, 50, 50, 40, question[0].splitlines())
-        pygame.gfxdraw.box(screen, pygame.Rect(0, theScreen.height * 0.1, theScreen.width, 75),
-                           (77, 153, 83, 130))
         A = text(text_color, a.x, a.y, 50, 50, 40, question[1].splitlines())
         B = text(text_color, b.x, b.y, 50, 50, 40, question[2].splitlines())
         C = text(text_color, c.x, c.y, 50, 50, 40, question[3].splitlines())
         D = text(text_color, d.x, d.y, 50, 50, 40, question[4].splitlines())
-        pygame.gfxdraw.box(screen, pygame.Rect(theScreen.width * 0.1, theScreen.height * 0.15,
-                                               600, 300), (77, 153, 83, 130))
+
+        #question box
+        #pygame.gfxdraw.box(screen, pygame.Rect(theScreen.width * 0.1, theScreen.height * 0.15,
+                                               #600, 300), box_color)
+
         q.draw(screen, int(theScreen.width*0.02), False)
         A.draw(screen, int(theScreen.width*0.015), False)
         B.draw(screen, int(theScreen.width*0.015), False)
         C.draw(screen, int(theScreen.width*0.015), False)
         D.draw(screen, int(theScreen.width*0.015), False)
 
-        guess = chooseAnswer(playerGroup, enemyGroup, question,level,q,A,B,C,D, ans_button_color)
+        guess = chooseAnswer(playerGroup, enemyGroup, question,level,q,A,B,C,D, ans_button_color,myPlayer,myEnemy)
         is_correct = get_result(guess, question[5])
 
         if is_correct:
@@ -948,18 +1003,22 @@ def theBattle(level, sounds=True):
                 animationController(playerGroup, enemyGroup, theScreen.width, theScreen.height, clock,level, "coffee break")
             return "win"
 
-def win(sounds=True):
-    if sounds:
+def win(sound):
+    if sound:
         pygame.mixer.music.load('victoire.mp3')
         pygame.mixer.music.play(-1)
 
-    print("You won!")
-    screen.fill((100, 100, 100))
+    print("Victory!")
+
+    screen.fill(gold)
+    fw = pygame.image.load("fireworks.png")
+    fw = pygame.transform.rotozoom(fw, 0, theScreen.width / 820)
+    screen.blit(fw, (theScreen.width * 0.2, theScreen.height * 0.25))
     snake = pygame.image.load("snake6.png")
     snake.convert()
-    # snake = pygame.transform.rotozoom(snake, 0, 0.7)
-    screen.blit(snake, (theScreen.width * 0.43, theScreen.height * 0.6))
-    winScreen = text(gold, (theScreen.width * 0.25), (theScreen.height * 0 / 12), (theScreen.width * 0.5),
+    snake = pygame.transform.rotozoom(snake, 0, theScreen.height / 600)
+    screen.blit(snake, (theScreen.width * 0.4, theScreen.height * 0.6))
+    winScreen = text(black, (theScreen.width * 0.25), (theScreen.height * 0 / 12), (theScreen.width * 0.5),
                             (theScreen.height * 2 / 10), 150,
                             ["You win!"])
     winScreen.draw(screen, int(theScreen.width*0.1), True)
@@ -967,20 +1026,24 @@ def win(sounds=True):
     pygame.display.update()
     pygame.time.delay(4000)
 
-def lose(sounds=True):
-    if sounds:
+def lose(sound):
+    if sound:
         pygame.mixer.music.load('defaite.mp3')
         pygame.mixer.music.play(-1)
 
-    print("You lost!")
-    screen.fill((100, 100, 100))
+    print("Defeat")
+    screen.fill(color_light)
+    rain = pygame.image.load("rain.png")
+    rain = pygame.transform.rotozoom(rain, 0, theScreen.width / 2000)
+    screen.blit(rain, (theScreen.width * 0.4, theScreen.height * 0.25))
+
     snake = pygame.image.load("snake5.png")
     snake.convert()
-    #snake = pygame.transform.rotozoom(snake, 0, 0.7)
-    screen.blit(snake, (theScreen.width * 0.4, theScreen.height * 0.6))
-    gameOver = text(gold, (theScreen.width * 0.25), (theScreen.height * 0 / 12), (theScreen.width * 0.5), (theScreen.height * 2 / 10),
+    snake = pygame.transform.rotozoom(snake, 0, theScreen.height / 600)
+    screen.blit(snake, (theScreen.width * 0.34, theScreen.height * 0.6))
+    gameOver = text(indigo, (theScreen.width * 0.25), (theScreen.height * 0 / 12), (theScreen.width * 0.5), (theScreen.height * 2 / 10),
                            150,
-                           ["GameOver"])
+                           ["You lose!"])
     gameOver.draw(screen, int(theScreen.width*0.1), True)
     clock.tick(2)
     pygame.display.update()
@@ -1000,7 +1063,6 @@ def options():
     while opt:
         for ev in pygame.event.get():
             pos = pygame.mouse.get_pos()
-
             if ev.type == pygame.QUIT:
                 pygame.quit()
                 quit()
@@ -1014,7 +1076,6 @@ def options():
                 if change_sound_settings.isOver(pos):
                     #sound_settings_menu()
                     return sound_settings_menu()
-                    opt = False
 
             if ev.type == pygame.VIDEORESIZE:
                 if (ev.w != theScreen.width):
@@ -1043,7 +1104,6 @@ def q_deck_menu():
     while opt:
         for ev in pygame.event.get():
             pos = pygame.mouse.get_pos()
-
             if ev.type == pygame.QUIT:
                 pygame.quit()
                 quit()
@@ -1078,14 +1138,17 @@ def q_deck_menu():
                 redraw_q_deck_window()
 
 #options -> change sound settings
-def redraw_sound_window(sounds=True):
+def redraw_sound_window():
     screen.fill(blue)
     sound_header.draw(screen, int(theScreen.width*0.1), True)
-    if sounds:
-        mute_button.draw(screen, int(theScreen.width*0.06), black, True)
-    else:
-        unmute_button.draw(screen, int(theScreen.width*0.06), black, True)
-    volume_label.draw(screen, int(theScreen.width*0.06), True)
+    unmute_button.draw(screen, int(theScreen.width*0.032), black, True)
+    mute_button.draw(screen, int(theScreen.width*0.032), black, True)
+    music_label.draw(screen, int(theScreen.width*0.05), True)
+    music_choice_1.draw(screen, int(theScreen.width*0.04), black, True)
+    music_choice_2.draw(screen, int(theScreen.width * 0.04), black, True)
+    music_choice_3.draw(screen, int(theScreen.width * 0.04), black, True)
+    music_choice_4.draw(screen, int(theScreen.width * 0.04), black, True)
+    music_choice_5.draw(screen, int(theScreen.width * 0.04), black, True)
     back_to_options.draw(screen, int(theScreen.width*0.04), black, True)
     pygame.display.update()
 
@@ -1098,18 +1161,45 @@ def sound_settings_menu():
             if ev.type == pygame.QUIT:
                 pygame.quit()
                 quit()
+
             if ev.type == pygame.MOUSEBUTTONDOWN:
                 if back_to_options.isOver(pos):
                     options()
                     opt = False
+                if music_choice_1.isOver(pos):
+                    pygame.mixer.music.load('8bit_game.mp3')
+                    pygame.mixer.music.play(-1)
+                    sound_settings_menu()
+                    return True, "8bit"
+                if music_choice_2.isOver(pos):
+                    pygame.mixer.music.load('idle.wav')
+                    pygame.mixer.music.play(-1)
+                    sound_settings_menu()
+                    return True, "elf"
+                if music_choice_3.isOver(pos):
+                    pygame.mixer.music.load('latin.wav')
+                    pygame.mixer.music.play(-1)
+                    sound_settings_menu()
+                    return True, "latin"
+                if music_choice_4.isOver(pos):
+                    pygame.mixer.music.load('elevator_music_16bit.wav')
+                    pygame.mixer.music.play(-1)
+                    sound_settings_menu()
+                    return True, "sinatra"
+                if music_choice_5.isOver(pos):
+                    pygame.mixer.music.load('lobby_rick_roll.wav')
+                    pygame.mixer.music.play(-1)
+                    sound_settings_menu()
+                    return True, "rick_roll"
+                if unmute_button.isOver(pos):
+                    pygame.mixer.music.unpause()
+                    sound_settings_menu()
+                    return False, "" #"unmuted"
                 if mute_button.isOver(pos):
                     pygame.mixer.music.pause()
-                    redraw_sound_window(False)
-                    return False
-                if unmute_button.isOver(pos):
-                    pygame.mixer.music.pause()
-                    redraw_sound_window(True)
-                    return True
+                    sound_settings_menu()
+                    return True, "" #"muted"
+
             if ev.type == pygame.VIDEORESIZE:
                 if (ev.w != theScreen.width):
                     theScreen.width = ev.w
@@ -1122,20 +1212,29 @@ def sound_settings_menu():
                 resize(theScreen.width, theScreen.height)
                 redraw_sound_window()
 
-def levelChange(screen, level, Enemy, enemyImg):
-    level = text(black, theScreen.width * 0.25, theScreen.height * 0.1, theScreen.width * 0.5,
+def levelChange(screen, level, Enemy, enemyImg, sound):
+    lev = text(black, theScreen.width * 0.25, theScreen.height * 0.1, theScreen.width * 0.5,
                         theScreen.height * 0.2, 200, ["LEVEL " + str(level)])
-    enemy = text(black, theScreen.width * 0.25, theScreen.height * 0.35, theScreen.width * 0.5,
-                        theScreen.height * 0.2, 100, ["Your enemy is " + Enemy])
+    if level == 1:
+        enemy = text(black, theScreen.width * 0.25, theScreen.height * 0.35, theScreen.width * 0.5,
+                     theScreen.height * 0.2, theScreen.width * 1/16, ["Warmup: Beat Java"])
+    elif level == 2:
+        enemy = text(black, theScreen.width * 0.25, theScreen.height * 0.35, theScreen.width * 0.5,
+                     theScreen.height * 0.2, theScreen.width * 1 / 16, ["Your enemy is Ruby"])
+    else:
+        enemy = text(black, theScreen.width * 0.25, theScreen.height * 0.35, theScreen.width * 0.5,
+                        theScreen.height * 0.2, theScreen.width * 0.01, ["Let's C if you can beat Eye"])
     screen.fill(gold)
-    enemyimg = pygame.image.load(enemyImg)
-    if Enemy == "Ruby":
-        enemyimg = pygame.transform.rotozoom(enemyimg, 0, 0.68)
-    elif Enemy == "Eye":
-        enemyimg = pygame.transform.rotozoom(enemyimg, 0, 0.85)
 
-    level.draw(screen, int(theScreen.width*0.2), True)
-    enemy.draw(screen, int(theScreen.width*0.1), True)
+    if sound:
+        pygame.mixer.music.load("elevator_music_16bit.wav")
+        pygame.mixer.music.play(0)
+
+    enemyimg = pygame.image.load(enemyImg)
+    enemyimg = pygame.transform.rotozoom(enemyimg, 0, theScreen.width / 2000)
+
+    lev.draw(screen, int(theScreen.width*0.2), True)
+    enemy.draw(screen, int(theScreen.width*0.07), True)
     if Enemy != "Eye":
         screen.blit(enemyimg, (theScreen.width * 0.4, theScreen.height * 0.55))
     else:
@@ -1151,26 +1250,40 @@ def main():
     enter_game = True
     restart_music = True
     sound = True
+    sound_str = ""
     while enter_game:
         if(sound and restart_music):
-            pygame.mixer.music.load('idle.wav')
-            pygame.mixer.music.play(-1)
+            if (sound_str == "8bit"):
+                pygame.mixer.music.load('8bit_game.mp3')
+                pygame.mixer.music.play(-1)
+            elif (sound_str == "latin"):
+                pygame.mixer.music.load('latin.wav')
+                pygame.mixer.music.play(-1)
+            elif (sound_str == "sinatra"):
+                pygame.mixer.music.load('elevator_music_16bit.wav')
+                pygame.mixer.music.play(-1)
+            elif (sound_str == "rick_roll"):
+                pygame.mixer.music.load('lobby_rick_roll.wav')
+                pygame.mixer.music.play(-1)
+            else: #sound_str == "elf" or ""
+                pygame.mixer.music.load('idle.wav')
+                pygame.mixer.music.play(-1)
 
-        # start screen
+        #start screen
         menuOption = startscreen()
 
-        #  go to start, options, or quit
+        #go to start, options, or quit
         if menuOption == "start":
             damageStats.modify(50,10)
-            levelChange(screen, 1, "Java", "coffee1.png")
+            levelChange(screen, 1, "Java", "coffee1.png", sound)
             result = theBattle(1, sound)
             restart_music = True
             if result == "win":
-                levelChange(screen, 2, "Ruby", "Ruby_idle.png")
+                levelChange(screen, 2, "Ruby", "Ruby_idle.png", sound)
                 damageStats.modify(25,25)
                 result2 = theBattle(2, sound)
                 if result2 == "win":
-                    levelChange(screen, 3, "Eye", "C1.png")
+                    levelChange(screen, 3, "Eye", "C1.png", sound)
                     damageStats.modify(17,25)
                     result3 = theBattle(3, sound)
                     if result3 == "win":
@@ -1182,10 +1295,20 @@ def main():
             else:
                 lose(sound)
         elif menuOption == "options":
+            sound = options()
+            sound_str = options()
             restart_music = False
-            if not options():
+            '''
+            if sound_str == "muted":
                 sound = False
-                #pygame.mixer.music.pause()
+            elif sound_str == "unmuted":
+                sound = True
+            elif sound_str != "":
+                sound = True
+            else: #sound_str == ""
+                sound = True
+                restart_music = False
+            '''
         elif menuOption == "quit":
             enter_game = False
             #restart_music = False
